django-linked-accounts README
==========================

This app handles linking Django auth.User accounts 
to other third-party service accounts including:

 * Facebook
 * Twitter
 * Google
 * Yahoo
 * LinkedIn

This package requires::

  oauth-flow
  httplib2
  oauth2
